@@ -1,9 +1,10 @@
 from __future__ import annotations
 
 import abc
-import ast
 import typing as t
 
+import ast_comments as ast
+
 from pyaphid.helpers import echo_with_line_ref
 
 
@@ -125,43 +126,56 @@ class ImportsTracker(metaclass=abc.ABCMeta):
 
 
 class CommentIgnore(metaclass=abc.ABCMeta):
-    _ignore_next = False
-    PYAPHID_IGNORE_COMMENT = "pyaphid:ignore"
+    PYAPHID_IGNORE_COMMENT = "#pyaphid:ignore"
 
     @abc.abstractmethod
     def generic_visit(self, node: ast.AST) -> t.Any:
         pass
 
-    def _ignore_comment_visit(self, node: ast.AST):
-        if (
-            node.comments  # type: ignore
-            and node.comments[0].replace(" ", "").lower() == self.PYAPHID_IGNORE_COMMENT  # type: ignore # noqa: E501
-        ):
-            self._ignore_next = True
+    def __init__(self, *args, **kwargs) -> None:
+        self._ignore_lines: list[int] = []
+
+    @classmethod
+    def _is_ignore_comment(cls, comment: str):
+        return comment.replace(" ", "").lower() == cls.PYAPHID_IGNORE_COMMENT
+
+    def check_ignore_comment_visit(self, node: ast.AST):
+        if hasattr(node, "body"):
+            for sub_node in node.body:  # type: ignore
+                if isinstance(sub_node, ast.Comment) and self._is_ignore_comment(
+                    sub_node.value
+                ):
+                    self._ignore_lines.append(sub_node.lineno)
+
+        self.generic_visit(node)
+        return node
+
+    def visit_Comment(self, node: ast.Comment):
+        if self._is_ignore_comment(node.value):
+            self._ignore_lines.append(node.lineno)
         self.generic_visit(node)
-        self._ignore_next = False
         return node
 
     def visit_Expr(self, node: ast.Expr):
-        return self._ignore_comment_visit(node)
+        return self.check_ignore_comment_visit(node)
 
     def visit_Return(self, node: ast.Return):
-        return self._ignore_comment_visit(node)
+        return self.check_ignore_comment_visit(node)
 
     def visit_With(self, node: ast.With):
-        return self._ignore_comment_visit(node)
+        return self.check_ignore_comment_visit(node)
 
     def visit_If(self, node: ast.If):
-        return self._ignore_comment_visit(node)
+        return self.check_ignore_comment_visit(node)
 
     def visit_AsyncWith(self, node: ast.AsyncWith):
-        return self._ignore_comment_visit(node)
+        return self.check_ignore_comment_visit(node)
 
     def visit_For(self, node: ast.For):
-        return self._ignore_comment_visit(node)
+        return self.check_ignore_comment_visit(node)
 
     def visit_AsyncFor(self, node: ast.AsyncFor):
-        return self._ignore_comment_visit(node)
+        return self.check_ignore_comment_visit(node)
 
 
 class ExpandedCallCollector(ast.NodeVisitor, ImportsTracker):
@@ -182,6 +196,7 @@ class VisitorMixIn(ImportsTracker, CommentIgnore):
         self.ignored_forbidden: list[list[str]] = []
         self.matches: list[CallMatch] = []
         self._nodes_in_class_context: list[ast.AST] = []
+        self._ignore_lines: list[int] = []
         return super().__init__()
 
     def is_forbidden(self, signature: str):
@@ -209,15 +224,15 @@ class VisitorMixIn(ImportsTracker, CommentIgnore):
             for target in node.targets:
                 if isinstance(target, ast.Name) and target.id in self.forbidden:
                     self._ignore_forbidden_assignment(target)
-
+        self.generic_visit(node)
         return node
 
     def visit_AnnAssign(self, node: ast.AnnAssign):
         if node not in self._nodes_in_class_context:
             if isinstance(node.target, ast.Name) and node.target.id in self.forbidden:
                 self._ignore_forbidden_assignment(node.target)
-
-            return node
+        self.generic_visit(node)
+        return node
 
     def _process_func_def(self, node: TFuncDef) -> TFuncDef:
         if node.name in self.forbidden and node not in self._nodes_in_class_context:
@@ -236,8 +251,9 @@ class VisitorMixIn(ImportsTracker, CommentIgnore):
 
     def visit_Call(self, node: ast.Call) -> ast.Call | None:
         expanded_call_signature = expand_call(node, self.imports, self.import_froms)
+        self.generic_visit(node)
         if (
-            not self._ignore_next
+            node.lineno not in self._ignore_lines
             and expanded_call_signature
             and self.is_forbidden(expanded_call_signature)
         ):
